from setuptools import setup, find_packages

setup(
    name="GamaWu",
    version="0.1.3",
    packages=find_packages(),
    description="for myself",
    author="Gama",
    author_email="wumian1996@gmail.com",
    python_requires=">=3.7"
)

